import { MessageTypes, TypedMessage } from "@metamask/eth-sig-util";
import { ETHAddress } from "@decloudlabs/stk-v2/lib/types/types";
export interface BaseParam {
    eventType: string;
    blockNumber: number;
}
export interface AppParam extends BaseParam {
    eventType: "update";
    nftID: string;
    appID: string;
    appName: string;
    appPath: string;
    modPath: string;
    subnetList: string[];
    multiplier: number[][];
    resourceCount: number[];
    resourceType: number[];
}
export interface AppBatchParam extends BaseParam {
    eventType: "update-batch";
    nftID: string;
    appList: {
        appID: string;
        appPath: string;
        modPath: string;
        subnetList: string[];
        multiplier: number[][];
        resourceCount: number[];
        resourceType: number[];
    };
}
export interface DeleteAppParam extends BaseParam {
    eventType: "delete";
    nftID: string;
    appID: string;
    subnetList: string[];
    appName: string;
}
export interface DeleteAppUsingNameParam extends BaseParam {
    eventType: "delete";
    nftID: string;
    appID?: string;
    subnetList: string[];
    appName: string;
}
export interface BalanceAddedParam extends BaseParam {
    eventType: "balance-added";
    nftID: string;
}
export interface BalanceWithdrawnParam extends BaseParam {
    eventType: "balance-withdrawn";
    nftID: string;
}
export interface CronBalanceTimeoutParam extends BaseParam {
    eventType: "balance-timeout";
    nftID: string;
}
export interface PaymentReceivedParam extends BaseParam {
    eventType: "payment-received";
    orderID: string;
    collectionID: string;
    amount: string;
    mintCount: number;
    receiverAddress: ETHAddress;
    filePath: string;
}
export type NFTEvent = PaymentReceivedParam;
export interface BlockEvents {
    blockNumber: number;
    eventList: NFTEvent[];
    lastReceivedTime: number;
    waitingStatus: boolean;
}
export interface NFTEventCollection {
    nftID: string;
    update: AppParam[];
    delete: DeleteAppParam[];
    balance?: BalanceAddedParam | BalanceWithdrawnParam | CronBalanceTimeoutParam;
}
export interface NFTExecutable {
    executionStatus: "idle" | "running" | "success" | "fail";
    nftEvent: NFTEvent;
}
export interface NFTEventMap {
    [index: string]: NFTEventCollection;
}
export type FetchedContractApp = [
    appID: string,
    subnetList: bigint[],
    multiplier: bigint[][],
    app: [
        appName: string,
        timestamp: bigint,
        path: [appPath: string, modPath: string],
        resourceType: bigint[],
        resourceCount: bigint[],
        cidLock: boolean
    ]
];
export interface NFTTrackMap {
    [nftID: string]: {
        balanceEndTime: Date;
    };
}
export interface NFTTrack {
    nftID: string;
    balanceEndTime: Date;
}
export interface NFTLog {
    nftID: string;
    logType: "success" | "operation" | "validation" | "error";
    logID: string;
    timestamp: Date;
    appID?: string;
    appName?: string;
    operation: string;
    message: string;
}
export interface ResourceUnit {
    memory: string;
    cpu: string;
    disk?: string;
}
export interface Port {
    containerPort: number;
    servicePort: number;
    hostUrl?: string;
    createFlag?: boolean;
}
export interface CreateAppVolumeMounts {
    mountPath: string;
    name: string;
}
export interface CreateAppEnvVariables {
    name: string;
    value: string;
}
export interface CreateAppImage {
    repository: string;
    tag: string;
}
export interface SystemLog {
    timestamp: Date;
    operation: string;
    message: string;
    logType: "operation" | "validation" | "error";
}
export interface APICallReturnSuccess<T> {
    success: true;
    data: T;
    statusCode?: number;
}
export interface APICallReturnError<E> {
    success: false;
    data: E;
    statusCode?: number;
}
export type APICallReturn<T, E = Error> = APICallReturnSuccess<T> | APICallReturnError<E>;
export interface AuthPayload {
    userAddress: string;
    signature: string;
    message: TypedMessage<MessageTypes>;
}
export interface BlockNumber {
    blockNumber: number;
    createTime: Date;
}
export interface LastBalanceScanTime {
    lastBalanceScanTime: Date;
}
export interface CFragUrsulaParams {
    nftID: string;
    appID: string;
    ursulaPath: string;
    clusterWalletAddress: string;
    userAuthPayload: AuthPayload;
    capsuleBytes: any;
    kfrag: any;
}
export interface KFragList {
    [index: number]: {
        kfrag: string;
        ursula: string;
    };
}
export interface CapsuleBytes {
    [index: number]: number;
}
export interface CipherText {
    [index: number]: number;
}
export interface CreatorKeys {
    address: string;
    publicKey: {
        [index: number]: number;
    };
    secretKey: string;
}
export interface KfragList {
    [index: number]: {
        kfrag: string;
        ursula: string;
    };
}
export interface APIStatusReturnSuccess<T> {
    success: true;
    statusCode: number;
    data: T;
}
export interface APIStatusReturnError<E> {
    success: false;
    statusCode: number;
    data: E;
}
export type APIStatusReturn<T, E = Error> = APIStatusReturnSuccess<T> | APIStatusReturnError<E>;
export interface HeartBeat {
    heartBeatTime: Date;
}
export interface ModifierArguments {
    modAttribVar?: {
        [index: string]: any;
    };
    resourceType?: number[];
    resourceCount?: number[];
}
export interface AppStatusLog extends NFTLog {
    appID: string;
    appName: string;
    logURL: string;
}
